@@ -81,9 +81,9 @@ Plack::App::* you should inherit from this directly.
 
 =item call ($env)
 
-You are expected to implement a C<call> method in your component. This is
-where all the work gets done. It receives the PSGI C<$env> hash-ref as an
-argument and is expected to return a proper PSGI response value.
+You are expected to implement a C<call> method in your component. This
+is where all the work gets done. It receives the PSGI C<$env> hash-ref
+as an argument and is expected to return a proper PSGI response value.
 
 =back
 
@@ -111,6 +111,21 @@ instead.
 
 =back
 
+=head1 OBJECT LIFECYCLE
+
+Objects for the derived classes (Plack::App::* or
+Plack::Middleware::*) are created at the PSGI application compile
+phase using C<new>, C<prepare_app> and C<to_app>, and the created
+object persists during the web server lifecycle, unless it is running
+on the non-persistent environment like CGI. C<call> is invoked against
+the same object whenever a new request comes in.
+
+You can check if it is running in a persistent environment by checking
+C<psgi.run_once> key in the C<$env> being true (non-persistent) or
+false (persistent), but it is best for you to write your middleware
+safe in the persistent environment. To accomplish that, you should
+avoid saving per-request data like C<$env> in your object.
+
 =head1 BACKWARDS COMPATIBILITY
 
 The L<Plack::Middleware> module used to inherit from L<Class::Accessor::Fast>,
